@@ -41,8 +41,8 @@
 #include <abstracttasksmodel.h>
 #include <startuptasksmodel.h>
 
-IconApplet::IconApplet(QObject *parent, const QVariantList &data)
-    : Plasma::Applet(parent, data)
+IconApplet::IconApplet(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plasma::Applet(parent, data, args)
 {
 }
 
@@ -128,7 +128,7 @@ void IconApplet::populate()
                 // if this restriction is set, KIO won't allow running desktop files from outside
                 // registered services, applications, and so on, in this case we'll use the original
                 // .desktop file and lose the ability to customize it
-                if (!KAuthorized::authorize(QStringLiteral("run_desktop_files"))) {
+                if (!KAuthorized::authorize(KAuthorized::RUN_DESKTOP_FILES)) {
                     populateFromDesktopFile(localUrlString);
                     // we don't call setLocalPath here as we don't want to store localPath to be a system-location
                     // so that the fact that we cannot edit is re-evaluated every time
@@ -230,7 +230,7 @@ void IconApplet::populate()
                     KDesktopFile(backingDesktopFile).desktopGroup().writeEntry(QStringLiteral("Icon"), job->iconFile());
 
                     m_iconName = job->iconFile();
-                    emit iconNameChanged(m_iconName);
+                    Q_EMIT iconNameChanged(m_iconName);
                 }
             });
         }
@@ -250,13 +250,13 @@ void IconApplet::populateFromDesktopFile(const QString &path)
     const QString &name = desktopFile.readName();
     if (m_name != name) {
         m_name = name;
-        emit nameChanged(name);
+        Q_EMIT nameChanged(name);
     }
 
     const QString &genericName = desktopFile.readGenericName();
     if (m_genericName != genericName) {
         m_genericName = genericName;
-        emit genericNameChanged(genericName);
+        Q_EMIT genericNameChanged(genericName);
     }
 
     setIconName(desktopFile.readIcon());
@@ -293,7 +293,7 @@ void IconApplet::setIconName(const QString &iconName)
     const QString newIconName = (!iconName.isEmpty() ? iconName : QStringLiteral("unknown"));
     if (m_iconName != newIconName) {
         m_iconName = newIconName;
-        emit iconNameChanged(newIconName);
+        Q_EMIT iconNameChanged(newIconName);
     }
 }
 
@@ -491,7 +491,7 @@ bool IconApplet::isAcceptableDrag(QObject *dropEvent)
     QMimeDatabase db;
     const QMimeType mimeType = db.mimeTypeForUrl(m_url);
 
-    if (KAuthorized::authorize(QStringLiteral("shell_access")) && isExecutable(mimeType)) {
+    if (KAuthorized::authorize(KAuthorized::SHELL_ACCESS) && isExecutable(mimeType)) {
         return true;
     }
 
@@ -575,6 +575,6 @@ void IconApplet::setLocalPath(const QString &localPath)
     config().writeEntry(QStringLiteral("localPath"), localPath);
 }
 
-K_PLUGIN_CLASS_WITH_JSON(IconApplet, "metadata.json")
+K_PLUGIN_CLASS_WITH_JSON(IconApplet, "package/metadata.json")
 
 #include "iconapplet.moc"
