@@ -1,32 +1,17 @@
-/***************************************************************************
- *   Copyright (C) 2014-2015 by Eike Hein <hein@kde.org>                   *
- *   Copyright (C) 2016-2017 by Ivan Cukic <ivan.cukic@kde.org>            *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014-2015 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2016-2017 Ivan Cukic <ivan.cukic@kde.org>
 
-#ifndef FAVORITESMODEL_H
-#define FAVORITESMODEL_H
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
+
+#pragma once
 
 #include "placeholdermodel.h"
 
 #include <QPointer>
 
 #include <KConfig>
-#include <KService>
 
 class PlaceholderModel;
 
@@ -115,5 +100,3 @@ private:
 
     KActivities::Consumer *m_activities;
 };
-
-#endif
