@@ -68,7 +68,7 @@ void ItemContainer::setKey(const QString &key)
 
     m_key = key;
 
-    emit keyChanged();
+    Q_EMIT keyChanged();
 }
 
 bool ItemContainer::editMode() const
@@ -117,12 +117,12 @@ void ItemContainer::setEditMode(bool editMode)
 
     if (m_dragActive != editMode && m_mouseDown) {
         m_dragActive = editMode && m_mouseDown;
-        emit dragActiveChanged();
+        Q_EMIT dragActiveChanged();
     }
 
     setConfigOverlayVisible(editMode);
 
-    emit editModeChanged(editMode);
+    Q_EMIT editModeChanged(editMode);
 }
 
 ItemContainer::EditModeCondition ItemContainer::editModeCondition() const
@@ -148,7 +148,7 @@ void ItemContainer::setEditModeCondition(EditModeCondition condition)
 
     setAcceptHoverEvents(condition == AfterMouseOver || (m_layout && m_layout->editMode()));
 
-    emit editModeConditionChanged();
+    Q_EMIT editModeConditionChanged();
 }
 
 AppletsLayout::PreferredLayoutDirection ItemContainer::preferredLayoutDirection() const
@@ -164,7 +164,7 @@ void ItemContainer::setPreferredLayoutDirection(AppletsLayout::PreferredLayoutDi
 
     m_preferredLayoutDirection = direction;
 
-    emit preferredLayoutDirectionChanged();
+    Q_EMIT preferredLayoutDirectionChanged();
 }
 
 void ItemContainer::setLayout(AppletsLayout *layout)
@@ -185,7 +185,7 @@ void ItemContainer::setLayout(AppletsLayout *layout)
     m_layout = layout;
 
     if (!layout) {
-        emit layoutChanged();
+        Q_EMIT layoutChanged();
         return;
     }
 
@@ -198,13 +198,13 @@ void ItemContainer::setLayout(AppletsLayout *layout)
             setEditMode(false);
         }
         if ((m_layout->editModeCondition() == AppletsLayout::Locked) != (m_editModeCondition == ItemContainer::Locked)) {
-            emit editModeConditionChanged();
+            Q_EMIT editModeConditionChanged();
         }
     });
     connect(m_layout, &AppletsLayout::editModeChanged, this, [this]() {
         setAcceptHoverEvents(m_editModeCondition == AfterMouseOver || m_layout->editMode());
     });
-    emit layoutChanged();
+    Q_EMIT layoutChanged();
 }
 
 AppletsLayout *ItemContainer::layout() const
@@ -248,7 +248,7 @@ void ItemContainer::setConfigOverlayComponent(QQmlComponent *component)
         m_configOverlay = nullptr;
     }
 
-    emit configOverlayComponentChanged();
+    Q_EMIT configOverlayComponentChanged();
 }
 
 ConfigOverlay *ItemContainer::configOverlayItem() const
@@ -269,7 +269,7 @@ void ItemContainer::setInitialSize(const QSizeF &size)
 
     m_initialSize = size;
 
-    emit initialSizeChanged();
+    Q_EMIT initialSizeChanged();
 }
 
 bool ItemContainer::configOverlayVisible() const
@@ -312,10 +312,10 @@ void ItemContainer::setConfigOverlayVisible(bool visible)
         m_configOverlayComponent->completeCreate();
 
         connect(m_configOverlay, &ConfigOverlay::openChanged, this, [this]() {
-            emit configOverlayVisibleChanged(m_configOverlay->open());
+            Q_EMIT configOverlayVisibleChanged(m_configOverlay->open());
         });
 
-        emit configOverlayItemChanged();
+        Q_EMIT configOverlayItemChanged();
     }
 
     if (m_configOverlay) {
@@ -376,8 +376,8 @@ void ItemContainer::geometryChanged(const QRectF &newGeometry, const QRectF &old
 {
     syncChildItemsGeometry(newGeometry.size());
     QQuickItem::geometryChanged(newGeometry, oldGeometry);
-    emit contentWidthChanged();
-    emit contentHeightChanged();
+    Q_EMIT contentWidthChanged();
+    Q_EMIT contentHeightChanged();
 }
 
 void ItemContainer::componentComplete()
@@ -487,7 +487,7 @@ bool ItemContainer::childMouseEventFilter(QQuickItem *item, QEvent *event)
         event->accept();
         m_dragActive = false;
         if (m_editMode) {
-            emit dragActiveChanged();
+            Q_EMIT dragActiveChanged();
         }
     }
 
@@ -516,7 +516,7 @@ void ItemContainer::mousePressEvent(QMouseEvent *event)
         grabMouse();
         setCursor(Qt::ClosedHandCursor);
         m_dragActive = true;
-        emit dragActiveChanged();
+        Q_EMIT dragActiveChanged();
     } else if (m_editModeCondition == AfterPressAndHold) {
         m_editModeTimer->start(QGuiApplication::styleHints()->mousePressAndHoldInterval());
     }
@@ -546,7 +546,7 @@ void ItemContainer::mouseReleaseEvent(QMouseEvent *event)
 
     m_dragActive = false;
     if (m_editMode) {
-        emit dragActiveChanged();
+        Q_EMIT dragActiveChanged();
         setCursor(Qt::OpenHandCursor);
     }
     event->accept();
@@ -574,7 +574,7 @@ void ItemContainer::mouseMoveEvent(QMouseEvent *event)
         m_layout->releaseSpace(this);
         grabMouse();
         m_dragActive = true;
-        emit dragActiveChanged();
+        Q_EMIT dragActiveChanged();
 
     } else {
         setPosition(QPointF(x() + event->windowPos().x() - m_lastMousePosition.x(), y() + event->windowPos().y() - m_lastMousePosition.y()));
@@ -583,7 +583,7 @@ void ItemContainer::mouseMoveEvent(QMouseEvent *event)
             m_layout->showPlaceHolderForItem(this);
         }
 
-        emit userDrag(QPointF(x(), y()), event->pos());
+        Q_EMIT userDrag(QPointF(x(), y()), event->pos());
     }
     m_lastMousePosition = event->windowPos();
     event->accept();
@@ -603,7 +603,7 @@ void ItemContainer::mouseUngrabEvent()
 
     m_dragActive = false;
     if (m_editMode) {
-        emit dragActiveChanged();
+        Q_EMIT dragActiveChanged();
     }
 }
 
@@ -664,7 +664,7 @@ void ItemContainer::setContentItem(QQuickItem *item)
 
     m_contentItem->setSize(QSizeF(width() - m_leftPadding - m_rightPadding, height() - m_topPadding - m_bottomPadding));
 
-    emit contentItemChanged();
+    Q_EMIT contentItemChanged();
 }
 
 QQuickItem *ItemContainer::background() const
@@ -683,7 +683,7 @@ void ItemContainer::setBackground(QQuickItem *item)
     m_backgroundItem->setPosition(QPointF(0, 0));
     m_backgroundItem->setSize(size());
 
-    emit backgroundChanged();
+    Q_EMIT backgroundChanged();
 }
 
 int ItemContainer::leftPadding() const
@@ -699,8 +699,8 @@ void ItemContainer::setLeftPadding(int padding)
 
     m_leftPadding = padding;
     syncChildItemsGeometry(size());
-    emit leftPaddingChanged();
-    emit contentWidthChanged();
+    Q_EMIT leftPaddingChanged();
+    Q_EMIT contentWidthChanged();
 }
 
 int ItemContainer::topPadding() const
@@ -716,8 +716,8 @@ void ItemContainer::setTopPadding(int padding)
 
     m_topPadding = padding;
     syncChildItemsGeometry(size());
-    emit topPaddingChanged();
-    emit contentHeightChanged();
+    Q_EMIT topPaddingChanged();
+    Q_EMIT contentHeightChanged();
 }
 
 int ItemContainer::rightPadding() const
@@ -733,8 +733,8 @@ void ItemContainer::setRightPadding(int padding)
 
     m_rightPadding = padding;
     syncChildItemsGeometry(size());
-    emit rightPaddingChanged();
-    emit contentWidthChanged();
+    Q_EMIT rightPaddingChanged();
+    Q_EMIT contentWidthChanged();
 }
 
 int ItemContainer::bottomPadding() const
@@ -750,8 +750,8 @@ void ItemContainer::setBottomPadding(int padding)
 
     m_bottomPadding = padding;
     syncChildItemsGeometry(size());
-    emit bottomPaddingChanged();
-    emit contentHeightChanged();
+    Q_EMIT bottomPaddingChanged();
+    Q_EMIT contentHeightChanged();
 }
 
 int ItemContainer::contentWidth() const
