@@ -1,24 +1,10 @@
 /*
- *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library/Lesser General Public License
- *   version 2, or (at your option) any later version, as published by the
- *   Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library/Lesser General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
 
-#ifndef PLASMA_PLASMAAPPLETITEMMODEL_P_H
-#define PLASMA_PLASMAAPPLETITEMMODEL_P_H
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#pragma once
 
 #include "kcategorizeditemsviewmodels_p.h"
 #include <KConfigGroup>
@@ -114,7 +100,5 @@ private:
     bool m_startupCompleted : 1;
 
 private Q_SLOTS:
-    void populateModel(const QStringList &whatChanged = QStringList());
+    void populateModel();
 };
-
-#endif /*PLASMAAPPLETSMODEL_H_*/
