@@ -1,25 +1,11 @@
 /*
- *   Copyright 2009 by Chani Armitage <chani@kde.org>
- *   Copyright 2018 by Eike Hein <hein@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2009 Chani Armitage <chani@kde.org>
+    SPDX-FileCopyrightText: 2018 Eike Hein <hein@kde.org>
 
-#ifndef SWITCHWINDOW_HEADER
-#define SWITCHWINDOW_HEADER
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#pragma once
 
 #include "ui_config.h"
 #include <plasma/containmentactions.h>
@@ -73,5 +59,3 @@ private:
     static TaskManager::TasksModel *s_tasksModel;
     static int s_instanceCount;
 };
-
-#endif
