@@ -170,7 +170,7 @@ void StatusNotifierItemSource::refreshToolTip()
 void StatusNotifierItemSource::refreshMenu()
 {
     if (m_menuImporter) {
-        m_menuImporter->deleteLater();
+        delete m_menuImporter;
         m_menuImporter = nullptr;
     }
     refresh();
