@@ -589,7 +589,7 @@ void EnvCanadaIon::slotJobFinished(KJob *job)
         forceImmediateUpdateOfAllVisualizations();
 
         // update the clients of our engine
-        emit forceUpdate(this, source);
+        Q_EMIT forceUpdate(this, source);
     }
 }
 
