@@ -19,7 +19,6 @@
 #include "xcursor/themeapplicator.h"
 #include "xcursor/thememodel.h"
 
-#include <KAboutData>
 #include <KIO/CopyJob>
 #include <KIO/DeleteJob>
 #include <KIO/Job>
@@ -46,8 +45,8 @@
 
 K_PLUGIN_FACTORY_WITH_JSON(CursorThemeConfigFactory, "kcm_cursortheme.json", registerPlugin<CursorThemeConfig>(); registerPlugin<CursorThemeData>();)
 
-CursorThemeConfig::CursorThemeConfig(QObject *parent, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, args)
+CursorThemeConfig::CursorThemeConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KQuickAddons::ManagedConfigModule(parent, data, args)
     , m_data(new CursorThemeData(this))
     , m_canInstall(true)
     , m_canResize(true)
@@ -58,15 +57,6 @@ CursorThemeConfig::CursorThemeConfig(QObject *parent, const QVariantList &args)
     qmlRegisterType<PreviewWidget>("org.kde.private.kcm_cursortheme", 1, 0, "PreviewWidget");
     qmlRegisterAnonymousType<SortProxyModel>("SortProxyModel",1);
     qmlRegisterAnonymousType<CursorThemeSettings>("CursorThemeSettings",1);
-    KAboutData *aboutData = new KAboutData(QStringLiteral("kcm_cursortheme"),
-                                           i18n("Cursors"),
-                                           QStringLiteral("1.0"),
-                                           QString(),
-                                           KAboutLicense::GPL,
-                                           i18n("(c) 2003-2007 Fredrik Höglund"));
-    aboutData->addAuthor(i18n("Fredrik Höglund"));
-    aboutData->addAuthor(i18n("Marco Martin"));
-    setAboutData(aboutData);
 
     m_themeModel = new CursorThemeModel(this);
 
@@ -110,7 +100,7 @@ void CursorThemeConfig::setCanInstall(bool can)
     }
 
     m_canInstall = can;
-    emit canInstallChanged();
+    Q_EMIT canInstallChanged();
 }
 
 bool CursorThemeConfig::canInstall() const
@@ -125,7 +115,7 @@ void CursorThemeConfig::setCanResize(bool can)
     }
 
     m_canResize = can;
-    emit canResizeChanged();
+    Q_EMIT canResizeChanged();
 }
 
 bool CursorThemeConfig::canResize() const
@@ -140,7 +130,7 @@ void CursorThemeConfig::setCanConfigure(bool can)
     }
 
     m_canConfigure = can;
-    emit canConfigureChanged();
+    Q_EMIT canConfigureChanged();
 }
 
 int CursorThemeConfig::preferredSize() const
@@ -154,7 +144,7 @@ void CursorThemeConfig::setPreferredSize(int size)
         return;
     }
     m_preferredSize = size;
-    emit preferredSizeChanged();
+    Q_EMIT preferredSizeChanged();
 }
 
 bool CursorThemeConfig::canConfigure() const
@@ -264,8 +254,8 @@ void CursorThemeConfig::updateSizeComboBox()
     } else {
         setCanResize(m_sizesModel->rowCount() > 0);
     }
-    // We need to emit a cursorSizeChanged in all case to refresh UI
-    emit cursorThemeSettings()->cursorSizeChanged();
+    // We need to Q_EMIT a cursorSizeChanged in all case to refresh UI
+    Q_EMIT cursorThemeSettings()->cursorSizeChanged();
 }
 
 int CursorThemeConfig::cursorSizeIndex(int cursorSize) const
@@ -308,7 +298,7 @@ void CursorThemeConfig::save()
     const CursorTheme *theme = selected.isValid() ? m_themeProxyModel->theme(selected) : nullptr;
 
     if (!applyTheme(theme, cursorThemeSettings()->cursorSize())) {
-        emit showInfoMessage(i18n("You have to restart the Plasma session for these changes to take effect."));
+        Q_EMIT showInfoMessage(i18n("You have to restart the Plasma session for these changes to take effect."));
     }
     removeThemes();
 
@@ -386,18 +376,18 @@ void CursorThemeConfig::installThemeFromFile(const QUrl &url)
 
     m_tempInstallFile.reset(new QTemporaryFile());
     if (!m_tempInstallFile->open()) {
-        emit showErrorMessage(i18n("Unable to create a temporary file."));
+        Q_EMIT showErrorMessage(i18n("Unable to create a temporary file."));
         m_tempInstallFile.reset();
         return;
     }
 
     m_tempCopyJob = KIO::file_copy(url, QUrl::fromLocalFile(m_tempInstallFile->fileName()), -1, KIO::Overwrite);
     m_tempCopyJob->uiDelegate()->setAutoErrorHandlingEnabled(true);
-    emit downloadingFileChanged();
+    Q_EMIT downloadingFileChanged();
 
     connect(m_tempCopyJob, &KIO::FileCopyJob::result, this, [this, url](KJob *job) {
         if (job->error() != KJob::NoError) {
-            emit showErrorMessage(i18n("Unable to download the icon theme archive: %1", job->errorText()));
+            Q_EMIT showErrorMessage(i18n("Unable to download the icon theme archive: %1", job->errorText()));
             return;
         }
 
@@ -428,14 +418,14 @@ void CursorThemeConfig::installThemeFile(const QString &path)
     }
 
     if (themeDirs.isEmpty()) {
-        emit showErrorMessage(i18n("The file is not a valid icon theme archive."));
+        Q_EMIT showErrorMessage(i18n("The file is not a valid icon theme archive."));
         return;
     }
 
     // The directory we'll install the themes to
     QString destDir = QDir::homePath() + "/.icons/";
     if (!QDir().mkpath(destDir)) {
-        emit showErrorMessage(i18n("Failed to create 'icons' folder."));
+        Q_EMIT showErrorMessage(i18n("Failed to create 'icons' folder."));
         return;
     }
 
@@ -472,7 +462,7 @@ void CursorThemeConfig::installThemeFile(const QString &path)
 
     archive.close();
 
-    emit showSuccessMessage(i18n("Theme installed successfully."));
+    Q_EMIT showSuccessMessage(i18n("Theme installed successfully."));
 
     m_themeModel->refreshList();
 }
