@@ -1,23 +1,10 @@
 /*
- * Copyright © 2003-2007 Fredrik Höglund <fredrik@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2003-2007 Fredrik Höglund <fredrik@kde.org>
 
-#ifndef PREVIEWWIDGET_H
-#define PREVIEWWIDGET_H
+    SPDX-License-Identifier: GPL-2.0-only
+*/
+
+#pragma once
 
 #include "sortproxymodel.h"
 #include <QPointer>
@@ -73,5 +60,3 @@ private:
     int m_currentIndex;
     int m_currentSize;
 };
-
-#endif // PREVIEWWIDGET_H
