@@ -33,21 +33,25 @@ CViewer::CViewer()
         exit(1);
     }
 
-    itsPreview = result.plugin;
+    m_preview = result.plugin;
 
-    actionCollection()->addAction(KStandardAction::Open, this, SLOT(fileOpen()));
+    m_openAct = actionCollection()->addAction(KStandardAction::Open, this, SLOT(fileOpen()));
     actionCollection()->addAction(KStandardAction::Quit, this, SLOT(close()));
     actionCollection()->addAction(KStandardAction::KeyBindings, this, SLOT(configureKeys()));
-    itsPrintAct = actionCollection()->addAction(KStandardAction::Print, itsPreview, SLOT(print()));
+    m_printAct = actionCollection()->addAction(KStandardAction::Print, m_preview, SLOT(print()));
 
-    itsPrintAct->setEnabled(false);
+    // Make tooltips more specific, instead of "document".
+    m_openAct->setToolTip(i18n("Open an existing font file"));
+    m_printAct->setToolTip(i18n("Print font preview"));
 
-    if (itsPreview->browserExtension()) {
-        connect(itsPreview->browserExtension(), &KParts::BrowserExtension::enableAction, this, &CViewer::enableAction);
+    m_printAct->setEnabled(false);
+
+    if (m_preview->browserExtension()) {
+        connect(m_preview->browserExtension(), &KParts::BrowserExtension::enableAction, this, &CViewer::enableAction);
     }
 
-    setCentralWidget(itsPreview->widget());
-    createGUI(itsPreview);
+    setCentralWidget(m_preview->widget());
+    createGUI(m_preview);
 
     setAutoSaveSettings();
     applyMainWindowSettings(KSharedConfig::openConfig()->group("MainWindow"));
@@ -73,7 +77,7 @@ void CViewer::fileOpen()
 void CViewer::showUrl(const QUrl &url)
 {
     if (url.isValid()) {
-        itsPreview->openUrl(url);
+        m_preview->openUrl(url);
     }
 }
 
@@ -88,7 +92,7 @@ void CViewer::configureKeys()
 void CViewer::enableAction(const char *name, bool enable)
 {
     if (0 == qstrcmp("print", name)) {
-        itsPrintAct->setEnabled(enable);
+        m_printAct->setEnabled(enable);
     }
 }
 
