@@ -10,6 +10,7 @@
 #include <KCModule>
 #include <KConfig>
 #include <KIO/Job>
+#include <KNS3/Button>
 #include <QSet>
 #include <QUrl>
 
@@ -59,7 +60,7 @@ public Q_SLOTS:
     void disableGroup();
     void changeText();
     void duplicateFonts();
-    void downloadFonts();
+    void downloadFonts(const QList<KNS3::Entry> &changedEntries);
     void print();
     void printGroup();
     void listingPercent(int p);
@@ -80,31 +81,32 @@ private:
     void doCmd(CJobRunner::ECommand cmd, const CJobRunner::ItemList &urls, bool system = false);
 
 private:
-    QSplitter *itsGroupSplitter, *itsPreviewSplitter;
-    CFontPreview *itsPreview;
-    CPreviewListView *itsPreviewList;
-    KConfig itsConfig;
-    QLabel *itsStatusLabel;
-    CProgressBar *itsListingProgress;
-    CFontList *itsFontList;
-    CFontListView *itsFontListView;
-    CGroupList *itsGroupList;
-    CGroupListView *itsGroupListView;
-    QPushButton *itsDeleteGroupControl, *itsEnableGroupControl, *itsDisableGroupControl, *itsAddFontControl, *itsGetNewFontsControl, *itsDeleteFontControl,
-        *itsScanDuplicateFontsControl;
-    CFontFilter *itsFilter;
-    QString itsLastStatusBarMsg;
-    KIO::Job *itsJob;
-    QProgressDialog *itsProgress;
-    CUpdateDialog *itsUpdateDialog;
-    QTemporaryDir *itsTempDir;
-    QProcess *itsPrintProc;
-    QSet<QString> itsDeletedFonts;
-    QList<QUrl> itsModifiedUrls;
-    CJobRunner *itsRunner;
-    QMenu *itsPreviewMenu, *itsPreviewListMenu;
-    QWidget *itsPreviewWidget;
-    bool itsPreviewHidden;
+    QSplitter *m_groupSplitter, *m_previewSplitter;
+    CFontPreview *m_preview;
+    CPreviewListView *m_previewList;
+    KConfig m_config;
+    QLabel *m_statusLabel;
+    CProgressBar *m_listingProgress;
+    CFontList *m_fontList;
+    CFontListView *m_fontListView;
+    CGroupList *m_groupList;
+    CGroupListView *m_groupListView;
+    QPushButton *m_deleteGroupControl, *m_enableGroupControl, *m_disableGroupControl, *m_addFontControl, *m_deleteFontControl,
+        *m_scanDuplicateFontsControl;
+    KNS3::Button *m_getNewFontsControl;
+    CFontFilter *m_filter;
+    QString m_lastStatusBarMsg;
+    KIO::Job *m_job;
+    QProgressDialog *m_progress;
+    CUpdateDialog *m_updateDialog;
+    QTemporaryDir *m_tempDir;
+    QProcess *m_printProc;
+    QSet<QString> m_deletedFonts;
+    QList<QUrl> m_modifiedUrls;
+    CJobRunner *m_runner;
+    QMenu *m_previewMenu, *m_previewListMenu;
+    QWidget *m_previewWidget;
+    bool m_previewHidden;
 };
 
 }
