@@ -20,7 +20,6 @@
 #include "../kcms-common_p.h"
 #include "styleconfdialog.h"
 
-#include <KAboutData>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -50,7 +49,7 @@
 K_PLUGIN_FACTORY_WITH_JSON(KCMStyleFactory, "kcm_style.json", registerPlugin<KCMStyle>(); registerPlugin<StyleData>();)
 
 extern "C" {
-Q_DECL_EXPORT void kcminit_style()
+Q_DECL_EXPORT void kcminit()
 {
     uint flags = KRdbExportQtSettings | KRdbExportQtColors | KRdbExportXftSettings | KRdbExportGtkTheme;
     KConfig _config(QStringLiteral("kcmdisplayrc"), KConfig::NoGlobals);
@@ -65,28 +64,17 @@ Q_DECL_EXPORT void kcminit_style()
 }
 }
 
-KCMStyle::KCMStyle(QObject *parent, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, args)
+KCMStyle::KCMStyle(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KQuickAddons::ManagedConfigModule(parent, data, args)
     , m_data(new StyleData(this))
     , m_model(new StylesModel(this))
 {
-    qmlRegisterUncreatableType<KCMStyle>("org.kde.private.kcms.style", 1, 0, "KCM", QStringLiteral("Cannot create instances of KCM"));
-    qmlRegisterType<StyleSettings>();
-    qmlRegisterType<StylesModel>();
+    auto uri = "org.kde.private.kcms.style";
+    qmlRegisterUncreatableType<KCMStyle>(uri, 1, 0, "KCM", QStringLiteral("Cannot create instances of KCM"));
+    qmlRegisterAnonymousType<StyleSettings>(uri, 1);
+    qmlRegisterAnonymousType<StylesModel>(uri, 1);
     qmlRegisterType<PreviewItem>("org.kde.private.kcms.style", 1, 0, "PreviewItem");
 
-    KAboutData *about = new KAboutData(QStringLiteral("kcm_style"),
-                                       i18n("Application Style"),
-                                       QStringLiteral("2.0"),
-                                       QString(),
-                                       KAboutLicense::GPL,
-                                       i18n("(c) 2002 Karol Szwed, Daniel Molkentin, (c) 2019 Kai Uwe Broulik "));
-
-    about->addAuthor(i18n("Karol Szwed"), QString(), QStringLiteral("gallium@kde.org"));
-    about->addAuthor(i18n("Daniel Molkentin"), QString(), QStringLiteral("molkentin@kde.org"));
-    about->addAuthor(i18n("Kai Uwe Broulik"), QString(), QStringLiteral("kde@broulik.de"));
-    setAboutData(about);
-
     connect(m_model, &StylesModel::selectedStyleChanged, this, [this](const QString &style) {
         styleSettings()->setWidgetStyle(style);
     });
@@ -134,7 +122,7 @@ void KCMStyle::setMainToolBarStyle(ToolBarStyle style)
 {
     if (m_mainToolBarStyle != style) {
         m_mainToolBarStyle = style;
-        emit mainToolBarStyleChanged();
+        Q_EMIT mainToolBarStyleChanged();
 
         const QMetaEnum toolBarStyleEnum = QMetaEnum::fromType<ToolBarStyle>();
         styleSettings()->setToolButtonStyle(toolBarStyleEnum.valueToKey(m_mainToolBarStyle));
@@ -151,7 +139,7 @@ void KCMStyle::setOtherToolBarStyle(ToolBarStyle style)
 {
     if (m_otherToolBarStyle != style) {
         m_otherToolBarStyle = style;
-        emit otherToolBarStyleChanged();
+        Q_EMIT otherToolBarStyleChanged();
 
         const QMetaEnum toolBarStyleEnum = QMetaEnum::fromType<ToolBarStyle>();
         styleSettings()->setToolButtonStyleOtherToolbars(toolBarStyleEnum.valueToKey(m_otherToolBarStyle));
@@ -173,14 +161,14 @@ void KCMStyle::configure(const QString &title, const QString &styleName, QQuickI
     QLibrary library(QPluginLoader(configPage).fileName());
     if (!library.load()) {
         qWarning() << "Failed to load style config page" << configPage << library.errorString();
-        emit showErrorMessage(i18n("There was an error loading the configuration dialog for this style."));
+        Q_EMIT showErrorMessage(i18n("There was an error loading the configuration dialog for this style."));
         return;
     }
 
     auto allocPtr = library.resolve("allocate_kstyle_config");
     if (!allocPtr) {
         qWarning() << "Failed to resolve allocate_kstyle_config in" << configPage;
-        emit showErrorMessage(i18n("There was an error loading the configuration dialog for this style."));
+        Q_EMIT showErrorMessage(i18n("There was an error loading the configuration dialog for this style."));
         return;
     }
 
@@ -218,7 +206,7 @@ void KCMStyle::configure(const QString &title, const QString &styleName, QQuickI
         }
 
         // Force re-rendering of the preview, to apply settings
-        emit styleReconfigured(styleName);
+        Q_EMIT styleReconfigured(styleName);
 
         // For now, ask all KDE apps to recreate their styles to apply the setitngs
         notifyKcmChange(GlobalChangeType::StyleChanged);
@@ -290,7 +278,7 @@ void KCMStyle::save()
             m_previousStyle = styleSettings()->widgetStyle();
         } else {
             const QString styleDisplay = m_model->data(m_model->index(m_model->indexOfStyle(styleSettings()->widgetStyle()), 0), Qt::DisplayRole).toString();
-            emit showErrorMessage(i18n("Failed to apply selected style '%1'.", styleDisplay));
+            Q_EMIT showErrorMessage(i18n("Failed to apply selected style '%1'.", styleDisplay));
 
             // Reset selected style back to current in case of failure
             styleSettings()->setWidgetStyle(m_previousStyle);
@@ -346,7 +334,7 @@ void KCMStyle::defaults()
 
 void KCMStyle::loadSettingsToModel()
 {
-    emit styleSettings()->widgetStyleChanged();
+    Q_EMIT styleSettings()->widgetStyleChanged();
 
     const QMetaEnum toolBarStyleEnum = QMetaEnum::fromType<ToolBarStyle>();
     setMainToolBarStyle(static_cast<ToolBarStyle>(toolBarStyleEnum.keyToValue(qUtf8Printable(styleSettings()->toolButtonStyle()))));
