@@ -25,6 +25,7 @@
 #include <KGlobalAccel>
 #include <KMessageBox>
 #include <KNotification>
+#include <KSystemClipboard>
 #include <KTextEdit>
 #include <KToggleAction>
 #include <KWindowSystem>
@@ -37,8 +38,6 @@
 #include "klipperpopup.h"
 #include "klippersettings.h"
 
-#include "systemclipboard.h"
-
 #include <prison/Prison>
 
 #include <config-X11.h>
@@ -112,9 +111,9 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config, KlipperMode mo
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/klipper"), this, QDBusConnection::ExportScriptableSlots);
 
     updateTimestamp(); // read initial X user time
-    m_clip = SystemClipboard::instance();
+    m_clip = KSystemClipboard::instance();
 
-    connect(m_clip, &SystemClipboard::changed, this, &Klipper::newClipData);
+    connect(m_clip, &KSystemClipboard::changed, this, &Klipper::newClipData);
 
     connect(&m_overflowClearTimer, &QTimer::timeout, this, &Klipper::slotClearOverflow);
 
@@ -881,7 +880,7 @@ void Klipper::editData(const QSharedPointer<const HistoryItem> &item)
     connect(buttons, &QDialogButtonBox::accepted, dlg.data(), &QDialog::accept);
     connect(buttons, &QDialogButtonBox::rejected, dlg.data(), &QDialog::reject);
     connect(dlg.data(), &QDialog::finished, dlg.data(), [this, dlg, item](int result) {
-        emit editFinished(item, result);
+        Q_EMIT editFinished(item, result);
         dlg->deleteLater();
     });
 
@@ -1007,7 +1006,7 @@ void Klipper::slotCycleNext()
     // do cycle and show popup only if we have something in clipboard
     if (m_history->first()) {
         m_history->cycleNext();
-        emit passivePopup(i18n("Clipboard history"), cycleText());
+        Q_EMIT passivePopup(i18n("Clipboard history"), cycleText());
     }
 }
 
@@ -1016,7 +1015,7 @@ void Klipper::slotCyclePrev()
     // do cycle and show popup only if we have something in clipboard
     if (m_history->first()) {
         m_history->cyclePrev();
-        emit passivePopup(i18n("Clipboard history"), cycleText());
+        Q_EMIT passivePopup(i18n("Clipboard history"), cycleText());
     }
 }
 
