@@ -1,23 +1,10 @@
-/* This file is part of the KDE project
+/*
 
-   Copyright (C) by Andrew Stanley-Jones <asj@cban.com>
-   Copyright (C) 2000 by Carsten Pfeiffer <pfeiffer@kde.org>
-   Copyright (C) 2004  Esben Mose Hansen <kde@mosehansen.dk>
+    SPDX-FileCopyrightText: Andrew Stanley-Jones <asj@cban.com>
+    SPDX-FileCopyrightText: 2000 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2004 Esben Mose Hansen <kde@mosehansen.dk>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "tray.h"
@@ -57,7 +44,7 @@ void KlipperTray::slotSetToolTipFromHistory()
         if (top->text().length() <= TOOLTIP_LENGTH_LIMIT) {
             setToolTipSubTitle(top->text());
         } else {
-            setToolTipSubTitle(top->text().left(TOOLTIP_LENGTH_LIMIT - 3) + QStringLiteral("..."));
+            setToolTipSubTitle(top->text().left(TOOLTIP_LENGTH_LIMIT - 1) + QStringLiteral("…"));
         }
     }
 }
