@@ -1,25 +1,10 @@
-/********************************************************************
-Copyright 2016  Eike Hein <hein.org>
+/*
+    SPDX-FileCopyrightText: 2016 Eike Hein <hein@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
-
-#ifndef TASKFILTERPROXYMODEL_H
-#define TASKFILTERPROXYMODEL_H
+#pragma once
 
 #include <QRect>
 #include <QSortFilterProxyModel>
@@ -53,6 +38,7 @@ class TASKMANAGER_EXPORT TaskFilterProxyModel : public QSortFilterProxyModel, pu
     Q_PROPERTY(bool filterByActivity READ filterByActivity WRITE setFilterByActivity NOTIFY filterByActivityChanged)
     Q_PROPERTY(bool filterNotMinimized READ filterNotMinimized WRITE setFilterNotMinimized NOTIFY filterNotMinimizedChanged)
     Q_PROPERTY(bool filterNotMaximized READ filterNotMaximized WRITE setFilterNotMaximized NOTIFY filterNotMaximizedChanged)
+    Q_PROPERTY(bool filterHidden READ filterHidden WRITE setFilterHidden NOTIFY filterHiddenChanged)
     Q_PROPERTY(bool filterSkipTaskbar READ filterSkipTaskbar WRITE setFilterSkipTaskbar NOTIFY filterSkipTaskbarChanged)
     Q_PROPERTY(bool filterSkipPager READ filterSkipPager WRITE setFilterSkipPager NOTIFY filterSkipPagerChanged)
 
@@ -230,6 +216,23 @@ public:
      **/
     void setFilterNotMaximized(bool filter);
 
+    /**
+     * Whether hidden tasks should be filtered. Defaults to
+     * @c false.
+     *
+     * @see setFilterHidden
+     * @returns @c true if hidden tasks should be filtered.
+     **/
+    bool filterHidden() const;
+
+    /**
+     * Set whether hidden tasks should be filtered.
+     *
+     * @see filterHidden
+     * @param filter Whether hidden tasks should be filtered.
+     **/
+    void setFilterHidden(bool filter);
+
     /**
      * Whether tasks which should be omitted from 'task bars' should be
      * filtered. Defaults to @c true.
@@ -304,6 +307,7 @@ Q_SIGNALS:
     void filterByActivityChanged() const;
     void filterNotMinimizedChanged() const;
     void filterNotMaximizedChanged() const;
+    void filterHiddenChanged() const;
     void filterSkipTaskbarChanged() const;
     void filterSkipPagerChanged() const;
     void demandingAttentionSkipsFiltersChanged() const;
@@ -318,5 +322,3 @@ private:
 };
 
 }
-
-#endif
