@@ -1,26 +1,10 @@
-/*****************************************************************
-ksmserver - the KDE session management server
+/*
+    ksmserver - the KDE session management server
 
-Copyright 2016 Martin Graesslin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2016 Martin Graesslin <mgraesslin@kde.org>
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
-AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
-AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-******************************************************************/
+    SPDX-License-Identifier: MIT
+*/
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QLibraryInfo>
@@ -40,7 +24,7 @@ int main(int argc, char *argv[])
 
     KWorkSpace::detectPlatform(argc, argv);
     QQuickWindow::setDefaultAlphaBuffer(true);
-    QApplication app(argc, argv);
+    QGuiApplication app(argc, argv);
 
     KQuickAddons::QtQuickSettings::init();
 
