@@ -1,21 +1,8 @@
 /*
- *   Copyright 2009 Aaron Seigo <aseigo@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2009 Aaron Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "appinterface.h"
 #include <config-X11.h>
@@ -158,6 +145,7 @@ bool AppInterface::coronaLocked() const
 
 void AppInterface::sleep(int ms)
 {
+    Q_UNUSED(ms)
     // TODO KF6 remove
 
     // Sleep was implemented with a nested event loop which would cause nested
@@ -202,12 +190,12 @@ QStringList AppInterface::knownWidgetTypes() const
 
 QStringList AppInterface::knownActivityTypes() const
 {
-    return knownContainmentTypes(QStringLiteral("desktop"));
+    return knownContainmentTypes(QStringLiteral("Desktop"));
 }
 
 QStringList AppInterface::knownPanelTypes() const
 {
-    return knownContainmentTypes(QStringLiteral("panel"));
+    return knownContainmentTypes(QStringLiteral("Panel"));
 }
 
 QStringList AppInterface::knownContainmentTypes(const QString &type) const
