@@ -20,7 +20,7 @@ class TestResolutions : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void testResolutions_data();
     void testResolutions();
 
